@@ -85,7 +85,7 @@ class BunkrCrawler:
                     build_id = json.loads(soup.select_one("script[id=__NEXT_DATA__]").get_text())
                     json_fetch = URL("https://" + url.host + "/_next/data/" + build_id['buildId'] + url.path + '.json')
                     text = await session.get_text(json_fetch)
-                    json_obj = json.loads(text)['pageProps']
+                    json_obj = {'props': json.loads(text)}
                 except:
                     raise Exception("Couldn't get link from HTML")
             link = URL(json_obj['props']['pageProps']['file']['mediafiles'] + '/' + json_obj['props']['pageProps']['file']['name'])
